# Miscellaneous tutorials
Here you can find a collection of miscellaneous tutorials - things which are useful to know, but
not essential to using AutoTrader.

```{toctree}
:maxdepth: 2
:hidden:

Host Email Account <host-email>
Continuous Mode <continuous-mode>
Single File Strategy <single-file-strat>
```